@@ -11,7 +11,7 @@ function(Envelope, Alpha, Global) {
     attr(Envelope, "desc")[5] <- "upper global envelope of %s from simulations"
     attr(Envelope, "einfo")$global <- TRUE
   } else {
-    Env <- apply(as.data.frame(Sims)[, -1], 1, quantile, probs=c(Alpha, 1-Alpha), na.rm=TRUE)
+    Env <- apply(as.data.frame(Sims)[, -1], 1, quantile, probs=c(Alpha/2, 1-Alpha/2), na.rm=TRUE)
     # quantile returns 0 when a value is NA. Force NA to appear in the result: add NA or 0.
     Env <- t(t(Env) + apply(as.data.frame(Sims), 1, sum)*0)
     attr(Envelope, "einfo")$nrank <- attr(Envelope, "einfo")$nsim*Alpha/2
